window.Gleam.initSearch([{"doc":"ask","title":"ask","content":"# ask\n\n[![Package Version](https://img.shields.io/hexpm/v/ask)](https://hex.pm/packages/ask)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/ask/)\n![CI](https://github.com/furrycatherder/gleam-ask/actions/workflows/tests.yml/badge.svg?branch=main)\n\n`ask` is a Gleam library tailored for simplifying the management of equivalences\nand predicates. Equivalences allow for the comparison of two values to\ndetermine if they&#39;re equivalent, while predicates assess if a given value meets\nspecific conditions.\n\n## Overview\n\n`ask` provides developers with a set of functions to create, combine, and\ntransform equivalences and predicates. Whether you&#39;re performing basic value\ncomparisons or intricate logical operations, `ask` furnishes the necessary tools\nto handle a variety of scenarios effectively.\n\n## Installation\n\n```sh\ngleam add ask\n```\n\n## Usage\n\n### Equivalences\n\n```gleam\nimport ask/equivalence\n\n// Defining custom equivalences\nlet eq1 = fn(x, y) { x % 3 == y % 3 }\nlet eq2 = fn(x, y) { x % 5 == y % 5 }\n\n// Combining equivalences using logical operations\nlet combined_eq = equivalence.and(eq1, eq2)\n\n// Using equivalence to compare values\nlet result = combined_eq(15, 30) // Returns True\n```\n\nEquivalences are expected to follow these friendly rules:\n\n- **Reflexivity**: Every value is equivalent to itself. It&#39;s like saying, &quot;Hey,\n  you&#39;re always equal to yourself!&quot;\n- **Symmetry**: If one value is equivalent to another, then it&#39;s a two-way\n  street! If X is like Y, then Y is like X. It&#39;s all about fairness!\n- **Transitivity**: Imagine a chain of equivalence! If X is equivalent to Y,\n  and Y is equivalent to Z, then it&#39;s like saying X is also buddies with Z.\n  Friendship circles all around!\n\nThese rules help keep our equivalences reliable and predictable, making sure\nthey play nice with each other.\n\n### Predicates\n\n```gleam\nimport ask/predicate\n\n// Defining custom predicates\nlet is_positive = fn(x) { x &gt; 0 }\nlet is_even = fn(x) { x % 2 == 0 }\n\n// Combining predicates using logical operations\nlet combined_pred = predicate.and(is_positive, is_even)\n\n// Using predicate to evaluate values\nlet result = combined_pred(6) // Returns True\nlet result = combined_pred(-6) // Returns False\n```\n\n## Conclusion\n\n`ask` equips Gleam developers with a robust toolkit for managing equivalences and\npredicates efficiently. Whether you&#39;re implementing algorithms, data validation\nsystems, or decision-making processes, `ask` facilitates streamlined code\ndevelopment, allowing you to focus on problem-solving.\n\nFurther documentation can be found at &lt;https://hexdocs.pm/ask&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n","url":"index.html"},{"doc":"ask/equivalence","title":"Equivalence","content":"pub type Equivalence(a) =\n  fn(a, a) -&gt; Bool\n\n\nSynonyms:\nask/equivalence.Equivalence\nask/equivalence Equivalence","url":"ask/equivalence.html#Equivalence"},{"doc":"ask/equivalence","title":"and","content":"pub fn and(\n  first: fn(a, a) -&gt; Bool,\n  second: fn(a, a) -&gt; Bool,\n) -&gt; fn(a, a) -&gt; Bool\n Combine two equivalences into a new equivalence that returns `True` if both\n equivalences return `True`.\n\nSynonyms:\nask/equivalence.and\nask/equivalence and","url":"ask/equivalence.html#and"},{"doc":"ask/equivalence","title":"list","content":"pub fn list(eq: fn(a, a) -&gt; Bool) -&gt; fn(List(a), List(a)) -&gt; Bool\n Create a new equivalence for a list of values based on the given equivalence.\n\nSynonyms:\nask/equivalence.list\nask/equivalence list","url":"ask/equivalence.html#list"},{"doc":"ask/equivalence","title":"map_input","content":"pub fn map_input(\n  over eq: fn(a, a) -&gt; Bool,\n  with fun: fn(b) -&gt; a,\n) -&gt; fn(b, b) -&gt; Bool\n Map the input of an equivalence to create a new equivalence.\n\nSynonyms:\nask/equivalence.map_input\nask/equivalence map_input","url":"ask/equivalence.html#map_input"},{"doc":"ask/equivalence","title":"not","content":"pub fn not(eq: fn(a, a) -&gt; Bool) -&gt; fn(a, a) -&gt; Bool\n Negate an equivalence to create a new equivalence that returns `True` if the\n original equivalence returns `False`.\n\nSynonyms:\nask/equivalence.not\nask/equivalence not","url":"ask/equivalence.html#not"},{"doc":"ask/equivalence","title":"or","content":"pub fn or(\n  first: fn(a, a) -&gt; Bool,\n  second: fn(a, a) -&gt; Bool,\n) -&gt; fn(a, a) -&gt; Bool\n Combine two equivalences into a new equivalence that returns `True` if either\n equivalence returns `True`.\n\nSynonyms:\nask/equivalence.or\nask/equivalence or","url":"ask/equivalence.html#or"},{"doc":"ask/equivalence","title":"pair","content":"pub fn pair(\n  first: fn(a, a) -&gt; Bool,\n  second: fn(b, b) -&gt; Bool,\n) -&gt; fn(#(a, b), #(a, b)) -&gt; Bool\n Create a new equivalence for a pair of values based on the given equivalences.\n\nSynonyms:\nask/equivalence.pair\nask/equivalence pair","url":"ask/equivalence.html#pair"},{"doc":"ask/equivalence","title":"trivial","content":"pub fn trivial() -&gt; fn(a, a) -&gt; Bool\n Create a new equivalence that always returns `True`.\n\n This is sometimes called the trivial or universal equivalence.\n\nSynonyms:\nask/equivalence.trivial\nask/equivalence trivial","url":"ask/equivalence.html#trivial"},{"doc":"ask/equivalence","title":"ask/equivalence","content":"","url":"ask/equivalence.html"},{"doc":"ask/predicate","title":"Predicate","content":"pub type Predicate(a) =\n  fn(a) -&gt; Bool\n\n\nSynonyms:\nask/predicate.Predicate\nask/predicate Predicate","url":"ask/predicate.html#Predicate"},{"doc":"ask/predicate","title":"all","content":"pub fn all(p: fn(a) -&gt; Bool) -&gt; fn(List(a)) -&gt; Bool\n Create a new predicate that returns `True` if it returns `True` for every\n element in a list.\n\nSynonyms:\nask/predicate.all\nask/predicate all","url":"ask/predicate.html#all"},{"doc":"ask/predicate","title":"always","content":"pub fn always() -&gt; fn(a) -&gt; Bool\n Create a new predicate that always returns `True`.\n\nSynonyms:\nask/predicate.always\nask/predicate always","url":"ask/predicate.html#always"},{"doc":"ask/predicate","title":"and","content":"pub fn and(\n  first: fn(a) -&gt; Bool,\n  second: fn(a) -&gt; Bool,\n) -&gt; fn(a) -&gt; Bool\n Combine two predicates together into a new predicate that returns `True` if\n both predicates return `True`.\n\nSynonyms:\nask/predicate.and\nask/predicate and","url":"ask/predicate.html#and"},{"doc":"ask/predicate","title":"any","content":"pub fn any(p: fn(a) -&gt; Bool) -&gt; fn(List(a)) -&gt; Bool\n Create a new predicate that returns `True` if it returns `True` for any\n element in a list.\n\nSynonyms:\nask/predicate.any\nask/predicate any","url":"ask/predicate.html#any"},{"doc":"ask/predicate","title":"every","content":"pub fn every(ps: List(fn(a) -&gt; Bool)) -&gt; fn(a) -&gt; Bool\n Combine a list of predicates together into a new predicate that returns `True`\n if all predicates return `True`.\n\nSynonyms:\nask/predicate.every\nask/predicate every","url":"ask/predicate.html#every"},{"doc":"ask/predicate","title":"map_input","content":"pub fn map_input(\n  over p: fn(a) -&gt; Bool,\n  with fun: fn(b) -&gt; a,\n) -&gt; fn(b) -&gt; Bool\n Map the input of a predicate to create a new predicate.\n\nSynonyms:\nask/predicate.map_input\nask/predicate map_input","url":"ask/predicate.html#map_input"},{"doc":"ask/predicate","title":"never","content":"pub fn never() -&gt; fn(a) -&gt; Bool\n Create a new predicate that always returns `False`.\n\nSynonyms:\nask/predicate.never\nask/predicate never","url":"ask/predicate.html#never"},{"doc":"ask/predicate","title":"not","content":"pub fn not(p: fn(a) -&gt; Bool) -&gt; fn(a) -&gt; Bool\n Negate a predicate.\n\nSynonyms:\nask/predicate.not\nask/predicate not","url":"ask/predicate.html#not"},{"doc":"ask/predicate","title":"or","content":"pub fn or(\n  first: fn(a) -&gt; Bool,\n  second: fn(a) -&gt; Bool,\n) -&gt; fn(a) -&gt; Bool\n Combine two predicates together into a new predicate that returns `True` if\n either predicate returns `True`.\n\nSynonyms:\nask/predicate.or\nask/predicate or","url":"ask/predicate.html#or"},{"doc":"ask/predicate","title":"some","content":"pub fn some(ps: List(fn(a) -&gt; Bool)) -&gt; fn(a) -&gt; Bool\n Combine a list of predicates together into a new predicate that returns `True`\n if any predicate returns `True`.\n\nSynonyms:\nask/predicate.some\nask/predicate some","url":"ask/predicate.html#some"},{"doc":"ask/predicate","title":"ask/predicate","content":"","url":"ask/predicate.html"}]);